<div align="center"><img src="https://raw.githubusercontent.com/obscraft23/pybedrock/main/docs/pybedrock.logo.png" width="600"/></div>

# pybedrock

[![](https://img.shields.io/pypi/v/pybedrock.svg?label=PyPI&style=flat-square)](https://pypi.org/pypi/pybedrock/)
[![](https://img.shields.io/pypi/pyversions/pybedrock.svg?label=Python&color=yellow&style=flat-square)](https://pypi.org/pypi/pybedrock/)
[![License](https://img.shields.io/badge/license-MIT-blue.svg?label=License&style=flat-square)](LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/pybedrock?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=Downloads&style=flat-square)](https://pepy.tech/project/pybedrock)

A python library for analysis and modification of world data in Minecraft Bedrock.

## Installation

```terminal
$ pip install pybedrock
```

## Supported versions

pybedrock supports Windoes, MacOS and Linux on various CPU architectures.

| | Windows AMD64 | MacOS x86_64 | MacOS arm64 | MacOS universal2 | Linux x86_64 | Linux i686 | Linux aarch64 | Linux ppc64le | Linux s390x |
|---------------|----|-----|-----|-----|-----|----|-----|-----|-----
| CPython 3.6   | ✅ | ✅ | N/A | N/A | ✅  | ✅  | ✅ | ✅  | ✅  |
| CPython 3.7   | ✅ | ✅| N/A | N/A | ✅ | ✅  | ✅ | ✅  | ✅  |
| CPython 3.8   | ✅ | ✅| ✅ | ✅ | ✅ | ✅  | ✅ | ✅  | ✅  |
| CPython 3.9   | ✅ | ✅| ✅ | ✅ | ✅ | ✅ | ✅ | ✅  | ✅  |
| CPython 3.10  | ✅ | ✅| ✅ | ✅ | ✅ | ✅  | ✅ | ✅  | ✅  |
| CPython 3.11  | ✅ | ✅| ✅ | ✅ | ✅ | ✅  | ✅ | ✅  | ✅  |
| PyPy 3.7 v7.3 | N/A | N/A | N/A | N/A | ✅ | ✅  | ✅ | N/A | N/A |
| PyPy 3.8 v7.3 | N/A | N/A | N/A | N/A | ✅ | ✅  | ✅ | N/A | N/A |
| PyPy 3.9 v7.3 | N/A | N/A | N/A | N/A | ✅ | ✅  | ✅ | N/A | N/A |

## Usage

**The document is under development.** </br>
Please see demostration codes as follows:

## Demonstrations

* Make a custom spawner (Google Colaboratory)

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/obscraft23/pybedrock/blob/main/demo/blockentity_demo.ipynb)

* Webapp to edit world data

https://mcbe-edit-web.vercel.app/

## Change log

## Contributing to the project

coming soon!

## License

This package is distributed under the [MIT license](https://github.com/obscraft23/pybedrock/blob/main/LICENSE).

## Credit
This package makes use of following repositories with modifications.

* [mcberepair](https://github.com/reedacartwright/mcberepair) by [reedacartwright](https://github.com/reedacartwright) <br>
[MIT License](https://github.com/reedacartwright/mcberepair/blob/master/LICENSE) Copyright (c) 2018-2019 Reed A. Cartwright <reed@cartwrig.ht>

* [leveldb-mcpe](https://github.com/Mojang/leveldb-mcpe) by [Mojang](https://github.com/Mojang) <br>
[BSD-3-Clause license](https://github.com/Mojang/leveldb-mcpe/blob/master/LICENSE) Copyright (c) 2011 The LevelDB Authors. All rights reserved.